import jieba
import chardet
import sys


def parse_args():
    print(sys.argv)
    return sys.argv[1], sys.argv[2]


def run():
    file, target = parse_args()
    charType = chardet.detect(open(file, 'rb').read())
    print(charType)
    with open(file,'r',errors='ignore', encoding=charType.get('encoding', 'utf-8')) as fp:
        lines = fp.readlines()
        for line in lines:
            seg_list = jieba.cut(line)
            with open(target, 'a+', encoding='utf-8') as ff:
               	ff.write(' '.join(seg_list))

if __name__ == '__main__':
    run()



import setuptools

with open('README.md', 'r') as f:
    long_description = f.read()

setuptools.setup(
    name='maketoken',
    version='0.0.3',
    author='flynn',
    author_email='fdoctor00@gmail.com',
    url='https://github.com/yunfengsay/makeToken',
    description=u'分词工具, 把文件中的词分割成token',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    install_requires=[
            'jieba',
            'chardet'
        ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        ]
)
